==> RsCMPX_Gprf-4.0.20.16-py3-none-any.whl: RsCMPX_Gprf/Implementations/Gprf/Measurement/FftSpecAn/Icomponent.py <==
from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Icomponent:
	"""Icomponent commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("icomponent", core, parent)

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:FFTSanalyzer:I \n
		Snippet: value: List[float] = driver.gprf.measurement.fftSpecAn.icomponent.read() \n
		Returns the measured normalized I and Q amplitudes in the time domain. \n
		Suppressed linked return values: reliability \n
			:return: idata: Comma-separated list of n normalized I or Q amplitudes. n equals the configured FFT length."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:GPRF:MEASurement<Instance>:FFTSanalyzer:I?', suppressed)
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:I \n
		Snippet: value: List[float] = driver.gprf.measurement.fftSpecAn.icomponent.fetch() \n
		Returns the measured normalized I and Q amplitudes in the time domain. \n
		Suppressed linked return values: reliability \n
			:return: idata: Comma-separated list of n normalized I or Q amplitudes. n equals the configured FFT length."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:I?', suppressed)
		return response

==> RsCMPX_Gprf-4.0.110-py3-none-any.whl: RsCMPX_Gprf/Implementations/Gprf/Measurement/FftSpecAn/Icomponent.py <==
from typing import List

from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from .....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IcomponentCls:
	"""Icomponent commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("icomponent", core, parent)

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:FFTSanalyzer:I \n
		Snippet: value: List[float] = driver.gprf.measurement.fftSpecAn.icomponent.read() \n
		Returns the measured normalized I and Q amplitudes in the time domain. \n
		Suppressed linked return values: reliability \n
			:return: idata: Comma-separated list of n normalized I or Q amplitudes. n equals the configured FFT length."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:GPRF:MEASurement<Instance>:FFTSanalyzer:I?', suppressed)
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:I \n
		Snippet: value: List[float] = driver.gprf.measurement.fftSpecAn.icomponent.fetch() \n
		Returns the measured normalized I and Q amplitudes in the time domain. \n
		Suppressed linked return values: reliability \n
			:return: idata: Comma-separated list of n normalized I or Q amplitudes. n equals the configured FFT length."""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:I?', suppressed)
		return response
